@@ -28,16 +28,20 @@ from sicor.ECMWF import ECMWF_variable
 
 
 def get_ecmwf_data(variable, image, options, logger=None):
-    """Wrapper for sicor.ECMWF.ECMWF_variable. For a given observation data, go back in time day by day
+    """
+    Wrapper for sicor.ECMWF.ECMWF_variable. For a given observation date, go back in time day by day
     in ECMWF database (given in options["ECMWF"]['path_db']) until a valid file is found. This time is set in
     options["ECMWF"]["max_delta_day"]. Adjust ECMWF step according to the days needed to go back in time until data
     was available.
-    :param variable: Name of ECMWF variable, need to be present in data base root directory
-    :param image: object derived from sicor.sensors.RSImage
-    :param options: dictionary with options, minimum is:
-    :param logger: None or instance of logging
-    {"ECMWF": {"path_db": [path to ecmwf db], "max_delta_day": [number of days], "target_resolution": 20}}
-    :return: numpy array with interpolated variable at given [target_resolution] for [variable] and [image] geo position
+
+    :param variable: Name of ECMWF variable, needs to be present in database root directory
+    :param image:    object derived from sicor.sensors.RSImage
+    :param options:  dictionary with options.
+                     Minimum is: {"ECMWF": {"path_db": [path to ecmwf db], "max_delta_day": [number of days],
+                     "target_resolution": 20}}
+    :param logger:   None or instance of logging
+    :return:         numpy array with interpolated variable at given [target_resolution] for [variable] and [image] geo
+                     position
     """
     logger = logger or logging.getLogger(__name__)
     ecmwf_xi = image.ecmwf_xi()
@@ -45,8 +49,11 @@ def get_ecmwf_data(variable, image, options, logger=None):
     delta_day = 0
     for delta_day in range(0, options["ECMWF"]["max_delta_day"]):
         try:
-            logger.warning("Look %i day back in time to find suitable ECMWF data." % delta_day)
-            return ECMWF_variable(variable=variable, path_db=options["ECMWF"]['path_db'],
+            if delta_day < 2:
+                logger.info("Look %i day back in time to find suitable ECMWF data." % delta_day)
+            else:
+                logger.info("Look %i days back in time to find suitable ECMWF data." % delta_day)
+            return ECMWF_variable(variable=variable, path_db=options["ECMWF"]['path_db'], delta_day=delta_day,
                                   var_date=sensing_date - timedelta(days=delta_day))(
                 shape=image.spatial_sampling_shapes[options["ECMWF"]["target_resolution"]],
                 lons=ecmwf_xi["lons"], lats=ecmwf_xi["lats"],
